pub trait PacketSocketProvider {
type Sock: Socket<Mac>;
// Required method
fn get_packet_socket(
&self,
) -> impl Future<Output = Result<Self::Sock, SocketError>>;
}Expand description
Provides access to AF_PACKET sockets.
Required Associated Types
Required Methods
Sourcefn get_packet_socket(
&self,
) -> impl Future<Output = Result<Self::Sock, SocketError>>
fn get_packet_socket( &self, ) -> impl Future<Output = Result<Self::Sock, SocketError>>
Gets a packet socket bound to the device on which the DHCP client protocol is being performed. The packet socket should already be bound to the appropriate device and protocol number.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.